@@ -1,4 +1,5 @@
 from functools import wraps
+from inspect import signature
 
 from unique_defaults import unique_builtins
 
@@ -15,6 +16,15 @@ def test_wraps():
     assert test.__doc__ == "test doc"
 
 
+def test_inspect():
+    def test(a, b, c={}, *args, d=set(), **kwargs):
+        return a, b, c, d
+
+    mutated_test = unique_builtins(test)
+
+    assert signature(test) == signature(mutated_test)
+
+
 def test_decorator():
     def decorator(func):
         return func
